Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1888)

Unified Diff: Source/web/FullscreenController.cpp

Issue 387233002: Introduce FullscreenElementStack::fullyExitFullscreen() (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: Created 6 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/core/html/HTMLMediaElement.cpp ('k') | Source/web/WebDocument.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/web/FullscreenController.cpp
diff --git a/Source/web/FullscreenController.cpp b/Source/web/FullscreenController.cpp
index 94a9ee5766d44f5826590a1ccc3f39ee244a9609..a18101de654d79c6dd6a06de41e8c853cd9a6373 100644
--- a/Source/web/FullscreenController.cpp
+++ b/Source/web/FullscreenController.cpp
@@ -117,10 +117,10 @@ void FullscreenController::willExitFullScreen()
if (!fullscreen)
return;
if (fullscreen->isFullScreen(*doc)) {
// When the client exits from full screen we have to call webkitCancelFullScreen to
// notify the document. While doing that, suppress notifications back to the client.
m_isCancelingFullScreen = true;
- fullscreen->webkitCancelFullScreen();
+ fullscreen->fullyExitFullscreen();
m_isCancelingFullScreen = false;
fullscreen->webkitWillExitFullScreenForElement(0);
if (RuntimeEnabledFeatures::overlayFullscreenVideoEnabled() && m_webViewImpl->layerTreeView())
@@ -117,10 +117,10 @@ void FullscreenController::willExitFullScreen()
return;
if (fullscreen->isFullScreen(*doc)) {
- // When the client exits from full screen we have to call webkitCancelFullScreen to
- // notify the document. While doing that, suppress notifications back to the client.
+ // When the client exits from full screen we have to call fullyExitFullscreen to notify
+ // the document. While doing that, suppress notifications back to the client.
m_isCancelingFullScreen = true;
« no previous file with comments | « Source/core/html/HTMLMediaElement.cpp ('k') | Source/web/WebDocument.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698